@@ -18,10 +18,11 @@
 
 import logging
 import subprocess
-from typing import Optional
+from typing import Optional, List, Type
 
 from .. import UnidentifiedError
 from ..fix_build import run_detecting_problems
+from ..session import Session
 
 
 class UnsatisfiedRequirements(Exception):
@@ -30,6 +31,12 @@ class UnsatisfiedRequirements(Exception):
 
 
 class Resolver(object):
+
+    name: str
+
+    def __init__(self, session, user_local):
+        raise NotImplementedError(self.__init__)
+
     def install(self, requirements):
         raise NotImplementedError(self.install)
 
@@ -44,13 +51,15 @@ class Resolver(object):
 
 
 class CPANResolver(Resolver):
+    name = "cpan"
+
     def __init__(self, session, user_local=False, skip_tests=True):
         self.session = session
         self.user_local = user_local
         self.skip_tests = skip_tests
 
     def __str__(self):
-        return "cpan"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -165,6 +174,7 @@ class TlmgrResolver(Resolver):
 
 
 class CTANResolver(TlmgrResolver):
+    name = "ctan"
 
     def __init__(self, session, user_local=False):
         super(CTANResolver, self).__init__(
@@ -172,13 +182,16 @@ class CTANResolver(TlmgrResolver):
 
 
 class RResolver(Resolver):
+
+    name: str
+
     def __init__(self, session, repos, user_local=False):
         self.session = session
         self.repos = repos
         self.user_local = user_local
 
     def __str__(self):
-        return "cran"
+        return self.name
 
     def __repr__(self):
         return "%s(%r, %r)" % (type(self).__name__, self.session, self.repos)
@@ -223,12 +236,14 @@ class RResolver(Resolver):
 
 
 class OctaveForgeResolver(Resolver):
+    name = "octave-forge"
+
     def __init__(self, session, user_local=False):
         self.session = session
         self.user_local = user_local
 
     def __str__(self):
-        return "octave-forge"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -269,6 +284,8 @@ class OctaveForgeResolver(Resolver):
 
 
 class CRANResolver(RResolver):
+    name = "cran"
+
     def __init__(self, session, user_local=False):
         super(CRANResolver, self).__init__(
             session, "http://cran.r-project.org", user_local=user_local
@@ -276,6 +293,8 @@ class CRANResolver(RResolver):
 
 
 class BioconductorResolver(RResolver):
+    name = "bioconductor"
+
     def __init__(self, session, user_local=False):
         super(BioconductorResolver, self).__init__(
             session, "https://hedgehog.fhcrc.org/bioconductor", user_local=user_local
@@ -283,12 +302,15 @@ class BioconductorResolver(RResolver):
 
 
 class HackageResolver(Resolver):
+
+    name = "hackage"
+
     def __init__(self, session, user_local=False):
         self.session = session
         self.user_local = user_local
 
     def __str__(self):
-        return "hackage"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -331,12 +353,15 @@ class HackageResolver(Resolver):
 
 
 class PypiResolver(Resolver):
+
+    name = "pypi"
+
     def __init__(self, session, user_local=False):
         self.session = session
         self.user_local = user_local
 
     def __str__(self):
-        return "pypi"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -382,12 +407,15 @@ class PypiResolver(Resolver):
 
 
 class GoResolver(Resolver):
+
+    name = "go"
+
     def __init__(self, session, user_local):
         self.session = session
         self.user_local = user_local
 
     def __str__(self):
-        return "go"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -428,17 +456,26 @@ NPM_COMMAND_PACKAGES = {
     "del-cli": "del-cli",
     "husky": "husky",
     "cross-env": "cross-env",
+    "xo": "xo",
+    "standard": "standard",
+    "jshint": "jshint",
+    "if-node-version": "if-node-version",
+    "babel": "babel",
+    "c8": "c8",
+    "prettier-standard": "prettier-standard",
 }
 
 
 class NpmResolver(Resolver):
+    name = "npm"
+
     def __init__(self, session, user_local=False):
         self.session = session
         self.user_local = user_local
         # TODO(jelmer): Handle user_local
 
     def __str__(self):
-        return "npm"
+        return self.name
 
     def __repr__(self):
         return "%s(%r)" % (type(self).__name__, self.session)
@@ -531,7 +568,7 @@ class StackedResolver(Resolver):
             raise UnsatisfiedRequirements(requirements)
 
 
-NATIVE_RESOLVER_CLS = [
+NATIVE_RESOLVER_CLS: List[Type[Resolver]] = [
     CPANResolver,
     CTANResolver,
     PypiResolver,
@@ -548,7 +585,31 @@ def native_resolvers(session, user_local):
     return StackedResolver([kls(session, user_local) for kls in NATIVE_RESOLVER_CLS])
 
 
-def auto_resolver(session, explain=False, system_wide: Optional[bool] = None):
+def select_resolvers(session, user_local, resolvers) -> Optional[Resolver]:
+    selected = []
+    for resolver in resolvers:
+        for kls in NATIVE_RESOLVER_CLS:
+            if kls.name == resolver:
+                selected.append(kls(session, user_local))
+                break
+        else:
+            if resolver == 'native':
+                selected.extend([kls(session, user_local) for kls in NATIVE_RESOLVER_CLS])
+            elif resolver == 'apt':
+                if user_local:
+                    raise NotImplementedError('user local not supported for apt')
+                from .apt import AptResolver
+                selected.append(AptResolver.from_session(session))
+            else:
+                raise KeyError(resolver)
+    if len(selected) == 0:
+        return None
+    if len(selected) == 1:
+        return selected[0]
+    return StackedResolver(selected)
+
+
+def auto_resolver(session: Session, explain: bool = False, system_wide: Optional[bool] = None):
     # if session is SchrootSession or if we're root, use apt
     from ..session.schroot import SchrootSession
     from ..session import get_user
